@@ -1,5 +1,5 @@
 from Naked.toolshed.shell import (muterun_js)
-import json, os
+import json, os, requests
 from eosjs_python.Exceptions import *
 
 
@@ -10,6 +10,7 @@ class Eos:
         self.http_address = config['http_address'] if 'http_address' in config else None
         self.key_provider = config[
             'key_provider'] if 'key_provider' in config else '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3'
+        self.chain_id = self.get_chain_id()
         if 'debug' in config:
             self.debug_mode = config['debug']
         else:
@@ -25,12 +26,43 @@ class Eos:
         else:
             raise GenerateKeysException(response.stderr)
 
+    @classmethod
+    def encrypt_chain_message(cls, privKeySender, pubKeyRecipient, message):
+        arguments = "'%s' '%s' '%s'" % (
+            privKeySender,
+            pubKeyRecipient,
+            message
+        )
+
+        response = muterun_js(cls.current_dir + '/js/Encrypt.js', arguments=arguments)
+        if response.exitcode == 0:
+            encrypted_msg = response.stdout.decode('utf8')
+            return encrypted_msg
+        else:
+            raise EncryptSecretException(response.stderr)
+
+    @classmethod
+    def decrypt_chain_message(cls, privKeyRecipient, pubKeySender, encryptedMessage):
+        arguments = "'%s' '%s' '%s'" % (
+            privKeyRecipient,
+            pubKeySender,
+            encryptedMessage
+        )
+
+        response = muterun_js(cls.current_dir + '/js/Decrypt.js', arguments=arguments)
+        if response.exitcode == 0:
+            plaintext = response.stdout.decode('utf8')
+            return plaintext
+        else:
+            raise EncryptSecretException(response.stderr)
+
     def newaccount(self, config):
         """
 		node CreateAccount.js 'http://172.18.0.1:8888' 'eosio' 'mytest12' '5KQwrPbwdL6PhXujxW37FSSQZ1JiwsST4cqQzDeyXtP79zkvFD3' '5JuaVWh3LDh1VH69urCdCa3A2YiQydbsLM1ZtGgsTXLYouxaTfc' 'EOS7vTHtMbZ1g9P8BiyAGD7Ni7H6UALVLVCW13xZrXT4heCBke3it' 'EOS8KKKYBBdwrmXRRynDXSxTX2qoT9TA4agahXXF4ccUgRCy81RNc' 8192 '100.0000 SYS' '100.0000 SYS' 0
 		"""
-        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s'" % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s'" % (
             self.http_address,
+            self.chain_id,
             config['creator'] if 'creator' in config else 'eosio',
             config['name'],
             self.key_provider,
@@ -43,8 +75,7 @@ class Eos:
         )
         response = muterun_js(self.current_dir + '/js/CreateAccount.js', arguments=arguments)
         if response.exitcode == 0:
-            data = self.load_data(response.stdout)
-            return data
+            return
         else:
             raise CreateAccountException(response.stderr)
 
@@ -52,8 +83,9 @@ class Eos:
         """
 		node PushContractTransaction.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eosio.token' 'transfer' 'eva' 'active' '{"from":"eva","to":"rider1","quantity":"1 EVA","memo":""}'
 		"""
-        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' " % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s'" % (
             self.http_address,
+            self.chain_id,
             self.key_provider,
             acct_contract,
             func_name,
@@ -69,8 +101,9 @@ class Eos:
             raise PushContractTransactionException(response.stderr)
 
     def get_table(self, code, scope, table, key_type='', index_position='', limit='', table_key='', lower_bound=''):
-        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' " % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s' '%s'" % (
             self.http_address,
+            self.chain_id,
             self.key_provider,
             code,
             scope,
@@ -92,8 +125,9 @@ class Eos:
         """
 		node GetCurrencyBalance.js 'http://127.0.0.1:8888' '5JhhMGNPsuU52XXjZ57FcDKvbb7KLrEhN65tdTQFrH51uruZLHi' 'eosio.token' 'xd455yhesww2' 'EVA'
 		"""
-        arguments = "'%s' '%s' '%s' '%s' '%s' " % (
+        arguments = "'%s' '%s' '%s' '%s' '%s' '%s'" % (
             self.http_address,
+            self.chain_id,
             self.key_provider,
             code,
             account,
@@ -106,9 +140,31 @@ class Eos:
         else:
             raise GetBalanceException(response.stderr)
 
+    def get_account(self, account_name):
+        """
+        nodejs GetAccount.js "https://eos.greymass.com:443" "WIF" "eosjacklucky"
+        """
+        arguments = "'%s' '%s' '%s' '%s'" % (
+            self.http_address,
+            self.chain_id,
+            self.key_provider,
+            account_name
+        )
+        response = muterun_js(self.current_dir + '/js/GetAccount.js', arguments=arguments)
+        if response.exitcode == 0:
+            data = self.load_data(response.stdout)
+            return data
+        else:
+            raise GetAccountException(response.stderr)
 
     def load_data(self, stdout):
         true_string = stdout.decode('utf8')
         if self.debug_mode:
             print(true_string)
         return json.loads(true_string)
+
+
+    def get_chain_id(self):
+        r = requests.get(self.http_address+"/v1/chain/get_info")
+        response = json.loads(r.text)
+        return response["chain_id"]
\ No newline at end of file
